/**
 *     Caption: Zaval GUI Designer Package
 *     $Revision: 1.51 $
 *     $Date: 2002/06/06 14:30:17 $
 *
 *     @author:     Andrei Vishnevsky
 *     @version:    1.0
 *
 * The Zaval GUI Designer Package (GDP) is set of components that allows to control
 * size, location, cursor types for the Java AWT/Swing components. Actually, the
 * components are Java AWT events listeners that have no GUI part.
 *
 * For more info on this product read Zaval GUI Designer Package Tutorial
 * (It comes within this package).
 * The latest product version is always available from the product's homepage:
 * http://www.zaval.org/products/gdp/
 * and from the SourceForge:
 * http://sourceforge.net/projects/zaval0004/
 *
 * Contacts:
 *   Support : support@zaval.org
 *   Change Requests : change-request@zaval.org
 *   Feedback : feedback@zaval.org
 *   Other : info@zaval.org
 *
 * Copyright (C) 2001-2002  Zaval Creative Engineering Group (http://www.zaval.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * (version 2) as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */
package org.zaval.awt;

import java.awt.*;
import java.util.*;

public class BorderPanel
extends Panel
{
  public static final int NONE   = 0;
  public static final int RAISED = 1;
  public static final int SUNKEN = 2;
  public static final int ETCHED = 3;
  public static final int PLAIN  = 4;

  private int borderType;

  public BorderPanel() {
    setBorderType(PLAIN);
  }

  public BorderPanel(int type) {
    setBorderType(type);
  }

  public Insets getInsets() {
    return new Insets(2, 2, 2, 2);
  }

  public void paint(Graphics g)
  {
    Dimension d = getSize();
    int xx = d.width  - 1;
    int yy = d.height - 1;
    leftLine  (g, 0, 0, xx, yy);
    rightLine (g, 0, 0, xx, yy);
    topLine   (g, 0, 0, xx, yy);
    bottomLine(g, 0, 0, xx, yy);
  }

  protected void leftLine(Graphics g, int x1, int y1, int x2, int y2)
  {
    g.setColor(Color.gray);
    switch(borderType)
    {
      case PLAIN:
      {
        g.setColor(Color.black);
        g.drawLine(x1, y1, x1, y2);
      } break;
      case ETCHED:
      {
        g.drawLine(x1, y1, x1, y2-1);
        g.setColor(Color.white);
        g.drawLine(x1 + 1, y1 + 1, x1 + 1, y2 - 2);
      } break;
      case RAISED:
      {
        g.setColor(Color.white);
        g.drawLine(x1, y1, x1, y2 - 1);
      } break;
      case SUNKEN:
      {
        g.drawLine(x1, y1, x1, y2 - 1);
        g.setColor(Color.black);
        g.drawLine(x1 + 1, y1 + 1, x1 + 1, y2 - 2);
      } break;
    }
  }

  protected void rightLine(Graphics g, int x1, int y1, int x2, int y2)
  {
    g.setColor(Color.gray);
    switch(borderType)
    {
      case PLAIN:
      {
        g.setColor(Color.black);
        g.drawLine(x2, y1, x2, y2);
      } break;
      case ETCHED:
      {
        g.drawLine(x2 - 1, y1, x2 - 1, y2 - 1);
        g.setColor(Color.white);
        g.drawLine(x2, y1 + 1, x2, y2);
      } break;
      case RAISED:
      {
        g.drawLine(x2 - 1, y1 + 1, x2 - 1, y2 - 1);
        g.setColor(Color.black);
        g.drawLine(x2, y1, x2, y2);
      } break;
      case SUNKEN:
      {
        g.setColor(Color.white);
        g.drawLine(x2, y1, x2, y2);
      } break;
    }
  }

  protected void topLine(Graphics g, int x1, int y1, int x2, int y2)
  {
    g.setColor(Color.gray);
    switch(borderType)
    {
      case PLAIN:
      {
        g.setColor(Color.black);
        g.drawLine(x1, y1, x2, y1);
      } break;
      case ETCHED:
      {
        g.drawLine(x1, y1, x2 - 1, y1);
        g.setColor(Color.white);
        g.drawLine(x1 + 1, y1 + 1, x2 - 2, y1 + 1);
      } break;
      case RAISED:
      {
        g.setColor(Color.white);
        g.drawLine(x1, y1, x2 - 1, y1);
      } break;
      case SUNKEN:
      {
        g.drawLine(x1, y1, x2 - 1, y1);
        g.setColor(Color.black);
        g.drawLine(x1 + 1, y1 + 1, x2 - 2, y1 + 1);
      } break;
    }
  }

  protected void bottomLine(Graphics g, int x1, int y1, int x2, int y2)
  {
    g.setColor(Color.gray);
    switch(borderType)
    {
      case PLAIN:
      {
        g.setColor(Color.black);
        g.drawLine(x1, y2, x2, y2);
      } break;
      case ETCHED:
      {
        g.drawLine(x1, y2 - 1, x2 - 1, y2 - 1);
        g.setColor(Color.white);
        g.drawLine(x1 + 1, y2, x2, y2);
      } break;
      case RAISED:
      {
        g.drawLine(x1 + 1, y2 - 1, x2 - 1, y2 - 1);
        g.setColor(Color.black);
        g.drawLine(x1, y2, x2, y2);
      } break;
      case SUNKEN:
      {
        g.setColor(Color.white);
        g.drawLine(x1, y2, x2, y2);
      } break;
    }
  }

  public void setBorderType(int t)
  {
    if(t != RAISED && t != SUNKEN && t != ETCHED && t != PLAIN && t != NONE) throw new IllegalArgumentException();
    if (t != borderType)
    {
      borderType = t;
      repaint();
    }
  }
}





