/**
 *     Caption: Zaval GUI Designer Package
 *     $Revision: 1.51 $
 *     $Date: 2002/06/06 14:30:17 $
 *
 *     @author:     Andrei Vishnevsky
 *     @version:    1.0
 *
 * The Zaval GUI Designer Package (GDP) is set of components that allows to control
 * size, location, cursor types for the Java AWT/Swing components. Actually, the
 * components are Java AWT events listeners that have no GUI part.
 *
 * For more info on this product read Zaval GUI Designer Package Tutorial
 * (It comes within this package).
 * The latest product version is always available from the product's homepage:
 * http://www.zaval.org/products/gdp/
 * and from the SourceForge:
 * http://sourceforge.net/projects/zaval0004/
 *
 * Contacts:
 *   Support : support@zaval.org
 *   Change Requests : change-request@zaval.org
 *   Feedback : feedback@zaval.org
 *   Other : info@zaval.org
 *
 * Copyright (C) 2001-2002  Zaval Creative Engineering Group (http://www.zaval.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * (version 2) as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */
package org.zaval.awt.gdp.demo;

import java.awt.*;
import java.util.*;

public class CodeGenerator
{
  public String generate(Component c) {
    return genPrefix() + generate(c, new int[] { 0 } ) + genSufix();
  }

  private String genPrefix ()
  {
    return "import java.awt.*;\n\n" +
           "public class Test\n" +
           "{\n" +
           " public static void main(String[] args)\n" +
           " {\n" +
           "  Frame frame = new Frame();\n" +
           "  frame.setSize(500, 500);\n"  +
           "  frame.setLayout(new BorderLayout());\n";
  }

  private String genSufix ()
  {
    return "  frame.add(\"Center\", comp0);\n" +
           "  frame.setVisible(true);\n"  +
           " }\n" +
           "}";
  }

  private String generate(Component c, int[] var)
  {
    if (c == null) return "";
    String cvar = "  comp" + var[0];
    String res  = "";

    if (c.getClass().getName().indexOf("FormPanel") >= 0)
      res += ("  " + "java.awt.Panel" + " " + cvar + "= new java.awt.Panel" + "();\n");
    else
      res += ("  " + c.getClass().getName() + " " + cvar + "= new " + c.getClass().getName() + "();\n");

    Dimension d = c.getSize();
    res += (cvar + ".setSize(" + d.width + "," + d.height + ");\n");

    Point p = c.getLocation();
    res += (cvar + ".setLocation(" + p.x + "," + p.y + ");\n");

    Color color = c.getBackground();
    res += (cvar + ".setBackground(" +
    "new Color(" + color.getRed() + "," + color.getGreen() + "," + color.getBlue()+ ")"+ ");\n");

    color = c.getForeground();
    res += (cvar + ".setForeground(" +
    "new Color(" + color.getRed() + "," + color.getGreen() + "," + color.getBlue()+ ")"+ ");\n");

    if (c instanceof Button)
     res += (cvar + ".setLabel(\"" + ((Button)c).getLabel() +  "\");\n");

    if (c instanceof Label)
     res += (cvar + ".setText(\"" + ((Label)c).getText() +  "\");\n");

    if (c instanceof TextComponent)
    {
      String text = ((TextComponent)c).getText();
      String rs = "";
      StringTokenizer st = new StringTokenizer(text, "\n");
      for (int i = 0;st.hasMoreTokens();i++)
      {
         String token = st.nextToken();
         if (i>0) rs += "\\n";
         rs += token;
      }
      res += (cvar + ".setText(\"" + rs +  "\");\n");
    }

    if (c instanceof Checkbox)
    {
      res += (cvar + ".setLabel(\"" + ((Checkbox)c).getLabel() +  "\");\n");
      res += (cvar + ".setState(" + ((Checkbox)c).getState() +  ");\n");
    }

    if (c instanceof List)
    {
      List     l     = (List)c;
      String[] items = l.getItems();
      for (int i = 0; i < items.length; i++)
        res += (cvar + ".addItem(\"" + items[i] +  "\");\n");

      int[] idx = l.getSelectedIndexes();
      for (int i = 0; i < idx.length; i++)
        res += (cvar + ".select(" + idx[i] +  ");\n");
    }

    if (c instanceof Container)
    {
      res += (cvar + ".setLayout(null);\n");
      Container cont = (Container)c;
      Component[] cc = cont.getComponents();
      for (int i=0; i<cc.length; i++)
      {
        int prev = var[0] + 1 + i;
        var[0] = prev;
        res += generate(cc[i], var);
        res += (cvar + ".add(" + ("comp" + prev) + ");\n");
      }
    }
    var[0] ++;
    return res;
  }
}
