/**
 *     Caption: Zaval GUI Designer Package
 *     $Revision: 1.51 $
 *     $Date: 2002/06/06 14:30:17 $
 *
 *     @author:     Andrei Vishnevsky
 *     @version:    1.0
 *
 * The Zaval GUI Designer Package (GDP) is set of components that allows to control
 * size, location, cursor types for the Java AWT/Swing components. Actually, the
 * components are Java AWT events listeners that have no GUI part.
 *
 * For more info on this product read Zaval GUI Designer Package Tutorial
 * (It comes within this package).
 * The latest product version is always available from the product's homepage:
 * http://www.zaval.org/products/gdp/
 * and from the SourceForge:
 * http://sourceforge.net/projects/zaval0004/
 *
 * Contacts:
 *   Support : support@zaval.org
 *   Change Requests : change-request@zaval.org
 *   Feedback : feedback@zaval.org
 *   Other : info@zaval.org
 *
 * Copyright (C) 2001-2002  Zaval Creative Engineering Group (http://www.zaval.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * (version 2) as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */
package org.zaval.awt.gdp.demo;

import java.awt.*;
import java.awt.event.*;
import java.util.*;
import java.io.*;
import java.lang.reflect.*;

import org.zaval.awt.*;
import org.zaval.awt.gdp.*;
import org.zaval.awt.gdp.event.*;

public class DemoUtil
{
   public static Color parseColor(String str)
   {
     if (str == null) return null;

     if (str.indexOf(',')>0)
     {
       try
       {
         StringTokenizer st = new StringTokenizer(str,",");
         int red   = Integer.parseInt(st.nextToken());
         int green = Integer.parseInt(st.nextToken());
         int blue  = Integer.parseInt(st.nextToken());
         return new Color(red, green, blue);
       }
       catch (NumberFormatException e)  {
         return null;
       }
     }

     Color color;
     color = parseNamedColor(str);
     if (color != null) return color;

     if (str.substring(0, 4).equalsIgnoreCase( "dark" ))
     {
       color = parseNamedColor(str.substring(4));
       if (color != null) return color.darker();
     }

     if (str.substring(0, 5).equalsIgnoreCase("light"))
     {
       color = parseNamedColor(str.substring(5));
       if (color != null) return color.brighter();
     }

     if (str.substring(0, 6).equalsIgnoreCase("bright"))
     {
       color = parseNamedColor(str.substring(6));
       if (color != null)  return color.brighter();
     }
     return null;
   }

  public static String[] getColorsNames()
  {
     String[] r = { "black", "blue", "cyan", "darkGray", "gray", "green", "lightGray", "magenta", "orange", "pink", "red", "white", "yellow" };
     return r;
  }

  private static Color parseNamedColor( String str )
  {
     if (str.equalsIgnoreCase("black" ) )   return Color.black;
     if (str.equalsIgnoreCase("blue" ) )    return Color.blue;
     if (str.equalsIgnoreCase("cyan" ) )    return Color.cyan;
     if (str.equalsIgnoreCase("darkGray"))  return Color.darkGray;
     if (str.equalsIgnoreCase("gray" ))     return Color.gray;
     if (str.equalsIgnoreCase("green" ))    return Color.green;
     if (str.equalsIgnoreCase("lightGray")) return Color.lightGray;
     if (str.equalsIgnoreCase("magenta"))   return Color.magenta;
     if (str.equalsIgnoreCase("orange"))    return Color.orange;
     if (str.equalsIgnoreCase("pink"))      return Color.pink;
     if (str.equalsIgnoreCase("red"))       return Color.red;
     if (str.equalsIgnoreCase("white"))     return Color.white;
     if (str.equalsIgnoreCase("yellow"))    return Color.yellow;
     return null;
   }

  public static String parseColor(Color color)
  {
     if (color == null) return null;

     if (color == Color.black) return "black";
     if (color == Color.blue) return "blue" ;
     if (color == Color.cyan) return "cyan";
     if (color == Color.darkGray) return "darkGray";
     if (color == Color.gray) return "gray" ;
     if (color == Color.green) return "green" ;
     if (color == Color.lightGray) return "lightGray";
     if (color == Color.magenta)  return "magenta";
     if (color == Color.orange) return "orange";
     if (color == Color.pink) return "pink";
     if (color == Color.red) return "red";
     if (color == Color.white) return "white";
     if (color == Color.yellow) return "yellow";

     return color.getRed() + "," + color.getGreen() + "," + color.getBlue();
  }
}
