/**
 *     Caption: Zaval GUI Designer Package
 *     $Revision: 1.51 $
 *     $Date: 2002/06/06 14:30:17 $
 *
 *     @author:     Andrei Vishnevsky
 *     @version:    1.0
 *
 * The Zaval GUI Designer Package (GDP) is set of components that allows to control
 * size, location, cursor types for the Java AWT/Swing components. Actually, the
 * components are Java AWT events listeners that have no GUI part.
 *
 * For more info on this product read Zaval GUI Designer Package Tutorial
 * (It comes within this package).
 * The latest product version is always available from the product's homepage:
 * http://www.zaval.org/products/gdp/
 * and from the SourceForge:
 * http://sourceforge.net/projects/zaval0004/
 *
 * Contacts:
 *   Support : support@zaval.org
 *   Change Requests : change-request@zaval.org
 *   Feedback : feedback@zaval.org
 *   Other : info@zaval.org
 *
 * Copyright (C) 2001-2002  Zaval Creative Engineering Group (http://www.zaval.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * (version 2) as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */
package org.zaval.awt.gdp.demo;

import java.awt.*;
import java.awt.event.*;
import java.beans.*;
import java.util.*;
import java.lang.reflect.*;

import org.zaval.awt.*;
import org.zaval.awt.gdp.*;
import org.zaval.awt.gdp.event.*;

public class FormManager
implements MouseListener, CursorInfo, DgnControllerListener,
           PropertyChangeListener, ComponentListener, ActionListener
{
  private ToolPanel tool;
  private FormPanel form;
  private GenPanel  gen;
  private CursorController formCC;
  private InspectorPanel   inspector;
  private Container        currentDgn;

  public FormManager() { }

  void setInspector (InspectorPanel p)
  {
    if (inspector != p)
    {
      if (inspector != null) inspector.removePropertyChangeListener(this);
      inspector = p;
      if (inspector != null) inspector.addPropertyChangeListener(this);
    }
  }

  void setGenPanel (GenPanel g)
  {
    if (g != gen)
    {
      if (gen != null) gen.getButton().removeActionListener(this);
      gen = g;
      if (gen != null) gen.getButton().addActionListener(this);
    }
  }

  void setToolPanel (ToolPanel t)
  {
    if (tool != t)
    {
      if (tool != null)
      {
        tool.getCleanButton().removeActionListener(this);
        tool.getCleanAllButton().removeActionListener(this);
      }
      tool = t;
      if (tool != null)
      {
        tool.getCleanButton().addActionListener(this);
        tool.getCleanAllButton().addActionListener(this);
      }
    }
  }

  void setFormPanel (FormPanel f)
  {
    if (form != f)
    {
      if (form != null)
      {
        form.removeMouseListener(this);
      }
      form = f;
      if (formCC == null) formCC = new CursorController(form, this);
      else                formCC.setTarget(form);
      if (form != null)
      {
        form.addMouseListener(this);
      }
    }
  }

  public void actionPerformed(ActionEvent e)
  {
    if (e.getSource() == gen.getButton())
    {
      DgnController.stopCurrentDgn();
      TextArea ta = gen.getTextArea();
      ta.setText ((new CodeGenerator()).generate(form));
    }
    else
    if (e.getSource() == tool.getCleanButton())
    {
      DgnController controller = DgnController.getCurrentDgn();
      if (controller != null)
      {
        DgnController.stopCurrentDgn();
        Component c = controller.getTarget();
        c.getParent().remove(c);
      }
    }
    else
    if (e.getSource() == tool.getCleanAllButton())
    {
      DgnController.stopCurrentDgn();
      form.removeAll();
    }
  }

  public void mouseReleased(MouseEvent e)
  {
    ToolItem item = tool.getSelected();
    if (item != null)
    {
      Component c = create (item);
      if (c != null)
      {
        DgnController dgn  = new DgnController(c);
        c.setVisible(false);
        ((Container)e.getComponent()).add (c);
        c.setLocation (e.getX(), e.getY());
        c.setVisible(true);
        dgn.addDgnControllerListener(this);
      }
      tool.clearSelection();
    }
    else {
      if (form == e.getSource()) DgnController.stopCurrentDgn();
    }
  }

  public void mouseClicked(MouseEvent e) {}
  public void mouseEntered(MouseEvent e) {}
  public void mouseExited(MouseEvent e) {}
  public void mousePressed(MouseEvent e)  {}

  public int getCursorType (Component target, int x, int y)
  {
    if (tool.getSelected() != null) return  Cursor.CROSSHAIR_CURSOR;
    return -1;
  }

  public void dgnStarted(DgnControllerEvent e)
  {
    if (inspector != null)
    {
      DgnController current = DgnController.getCurrentDgn();
      currentDgn = current.getDgnContainer();
      currentDgn.addComponentListener(this);

      Component target = (Component)e.getSource();
      String[] names = PropertyResolver.getPropertyNames(target);

      for (int i=0;i<names.length;i++)
        inspector.addProperty(names[i], PropertyResolver.getValueAsString(target, names[i]));
      inspector.getParent().invalidate();
      inspector.getParent().validate();
      inspector.getParent().doLayout();
      inspector.repaint();
    }
  }

  public void dgnFinished(DgnControllerEvent e)
  {
    if (inspector != null)
    {
      currentDgn.removeComponentListener(this);
      currentDgn = null;
      inspector.removeAllProps();
      inspector.getParent().invalidate();
      inspector.getParent().validate();
    }
  }

  public void propertyChange(PropertyChangeEvent e)
  {
    DgnController current = DgnController.getCurrentDgn();
    Component target = current.getTarget();
    Object    value  = PropertyResolver.convert2val(e.getPropertyName(), (String)e.getNewValue());
    PropertyResolver.setValue(target, e.getPropertyName(), value);
  }

  public void componentShown (ComponentEvent e)
  {
    if (e.getComponent() == currentDgn)
    {
      DgnController current = DgnController.getCurrentDgn();
      Component t = current.getTarget();
      Dimension d = t.getSize();
      Point     p1 = currentDgn.getLocation();
      Point     p2 = t.getLocation();
      p1.x = p1.x + p2.x;
      p1.y = p1.y + p2.y;
      inspector.setPropertyValue("Location", "" + p1.x + "," + p1.y);
      inspector.setPropertyValue("Size", "" + d.width + "," + d.height);
    }
  }

  public void componentResized(ComponentEvent e) {}
  public void componentMoved (ComponentEvent e) {}
  public void componentHidden(ComponentEvent e) {}

  protected Component create(ToolItem item)
  {
    Component c  = null;
    try {
      Class cl = Class.forName(item.className);
      if (item.args != null)
      {
        Class [] argsTypes  = new Class[1];
        Object[] argsValues = new Object[1];
        try {
          int value = Integer.parseInt(item.args);
          argsTypes[0] = Integer.TYPE;
          Constructor constr = cl.getConstructor(argsTypes);
          argsValues[0] = new Integer(value);
          c = (Component)constr.newInstance(argsValues);
        }
        catch (Exception eee) {}
        if (c == null)
        {
          argsTypes[0]  = String.class;
          argsValues[0] = "" + item.args;
          Constructor constr = cl.getConstructor(argsTypes);
          c = (Component)constr.newInstance(argsValues);
        }
      }
      else c = (Component)cl.newInstance();

      c.setBackground(new Color (0xCC, 0xCC, 0xCC));
      c.setVisible(true);
      c.setSize(item.size);
      if (c instanceof Container)
      {
        ((Container)c).setLayout(null);
        c.addMouseListener(this);
        new CursorController(c, this);
      }

      if (c instanceof List)
      {
        ((List)c).addItem ("Item 1");
        ((List)c).addItem ("Item 2");
      }
    }
    catch (Exception ee) {
      ee.printStackTrace();
      c = null;
    }
    return c;
  }
}



