/**
 *     Caption: Zaval GUI Designer Package
 *     $Revision: 1.51 $
 *     $Date: 2002/06/06 14:30:17 $
 *
 *     @author:     Andrei Vishnevsky
 *     @version:    1.0
 *
 * The Zaval GUI Designer Package (GDP) is set of components that allows to control
 * size, location, cursor types for the Java AWT/Swing components. Actually, the
 * components are Java AWT events listeners that have no GUI part.
 *
 * For more info on this product read Zaval GUI Designer Package Tutorial
 * (It comes within this package).
 * The latest product version is always available from the product's homepage:
 * http://www.zaval.org/products/gdp/
 * and from the SourceForge:
 * http://sourceforge.net/projects/zaval0004/
 *
 * Contacts:
 *   Support : support@zaval.org
 *   Change Requests : change-request@zaval.org
 *   Feedback : feedback@zaval.org
 *   Other : info@zaval.org
 *
 * Copyright (C) 2001-2002  Zaval Creative Engineering Group (http://www.zaval.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * (version 2) as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */
package org.zaval.awt.gdp.demo;

import java.beans.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;
import java.io.*;
import java.lang.reflect.*;

import org.zaval.awt.*;
import org.zaval.awt.gdp.*;
import org.zaval.awt.gdp.event.*;

public class InspectorPanel
extends Panel
implements LayoutManager, MouseListener, FocusListener,
           KeyListener, DgnComponent
{
  private Hashtable properties = new Hashtable();
  private Vector    vproperties = new Vector();
  private int nameColWidth  = 80;
  private int valueColWidth = 80;
  private int cellHeight = 20;
  private int xgap = 4, ygap = 1;
  private Label nameTitle, valueTitle;
  private PropertyChangeSupport support;
  private PropertyDesc selected;

  public InspectorPanel()
  {
    setLayout(this);
    setBackground (Color.lightGray);
    nameTitle  = new Label ("Name");
    valueTitle = new Label ("Value");
    Font font = new Font ("HELVETICA", Font.BOLD, 12);
    nameTitle.setFont (font);
    valueTitle.setFont(font);
    add (nameTitle);
    add (valueTitle);
  }

  public void addPropertyChangeListener(PropertyChangeListener l) {
    if (support == null) support = new PropertyChangeSupport(this);
    support.addPropertyChangeListener(l);
  }

  public void removePropertyChangeListener(PropertyChangeListener l) {
    if (support != null) support.removePropertyChangeListener(l);
  }

  public void addProperty(String name, String value)
  {
    escapeEdit();
    if (properties.get(name) == null)
    {
      PropertyDesc d = new PropertyDesc();
      d.nameView  = new Label(name);
      d.valueView = new Label(value);
      d.editor    = new TextField ("");
      d.valueView.addMouseListener(this);
      d.editor.addFocusListener(this);
      d.editor.addKeyListener(this);
      add (d.nameView);
      add (d.valueView);
      properties.put(name, d);
      vproperties.addElement(d);
    }
  }

  public void removeProperty(String name)
  {
    escapeEdit();
    PropertyDesc d = (PropertyDesc)properties.get(name);
    if (d != null)
    {
      remove(d.nameView);
      remove(d.valueView);
      d.valueView.removeMouseListener(this);
      d.editor.removeFocusListener(this);
      d.editor.removeKeyListener(this);
      properties.remove(name);
      vproperties.removeElement(d);
    }
  }

  public void removeAllProps() {
    for (Enumeration en = properties.keys(); en.hasMoreElements(); )
      removeProperty((String)en.nextElement());
  }

  public void setPropertyValue(String name, String value)
  {
    escapeEdit();
    PropertyDesc d = (PropertyDesc)properties.get(name);
    if (d != null)
    {
      d.valueView.setText (value);
      repaint();
    }
  }

  public void layoutContainer(Container p)
  {
    Insets in = p.getInsets();
    Dimension ps1 = nameTitle.getPreferredSize();
    if (ps1.width < nameColWidth)
    {
      nameTitle.setLocation(in.left + (nameColWidth - ps1.width)/2, in.top);
      nameTitle.setSize(ps1.width, cellHeight);
    }
    else
    {
      nameTitle.setSize(nameColWidth, cellHeight);
      nameTitle.setLocation(in.left, in.top);
    }

    Dimension ps2 = valueTitle.getPreferredSize();
    if (ps2.width < valueColWidth)
    {
      valueTitle.setLocation(in.left + valueColWidth + xgap + (valueColWidth - ps2.width)/2, in.top);
      valueTitle.setSize(ps2.width, cellHeight);
    }
    else
    {
      valueTitle.setLocation(in.left + valueColWidth + xgap, in.top);
      valueTitle.setSize(valueColWidth, cellHeight);
    }

    int y = in.top  + cellHeight   + ygap;
    int x = in.left + nameColWidth + xgap;
    for (int i=0; i < vproperties.size(); i++)
    {
      PropertyDesc desc = (PropertyDesc)vproperties.elementAt(i);
      desc.nameView.setLocation(in.left, y);
      desc.valueView.setLocation(x, y);
      desc.editor.setLocation(x, y);
      desc.nameView.setSize(nameColWidth, cellHeight);
      desc.valueView.setSize(valueColWidth, cellHeight);
      desc.editor.setSize(valueColWidth, cellHeight);
      y += (cellHeight + ygap);
    }
  }

  public Dimension preferredLayoutSize(Container p)
  {

    Insets in = p.getInsets();
    int size = properties.size();
    return new Dimension(in.left + in.right  + nameColWidth + valueColWidth + xgap,
                         in.top  + in.bottom + cellHeight * (size + 2) + size*ygap);

  }

  public Dimension minimumLayoutSize(Container p) {
    return preferredLayoutSize(p);
  }

  public void addLayoutComponent(String name, Component comp) {}

  public void removeLayoutComponent(Component comp) {}

  public void paint(Graphics g)
  {
    super.paint (g);
    int    size = properties.size();
    Insets in = getInsets();
    Dimension d = getSize();
    g.setColor(Color.black);
    int y = cellHeight + in.top;
    int w = Math.min(d.width - in.left - in.right, nameColWidth + valueColWidth + ygap);
    for (int i=0; i<size; i++)
    {
      g.drawLine (in.left, y, in.left + w, y);
      y += (cellHeight + ygap);
    }
    g.drawLine (in.left + nameColWidth, in.top,
                in.left + nameColWidth, in.top + (size + 1)*cellHeight + size*ygap);
  }

  public void mouseClicked(MouseEvent e) { }
  public void mouseEntered(MouseEvent e) {}
  public void mouseExited(MouseEvent e) { }

  public void mousePressed(MouseEvent e)
  {
    Component src = e.getComponent();
    for (Enumeration en = properties.elements(); en.hasMoreElements();)
    {
      PropertyDesc desc = (PropertyDesc)en.nextElement();
      if (desc.valueView == src)
      {
        endEdit();
        startEdit(desc);
        break;
      }
    }
  }

  public void mouseReleased(MouseEvent e) {}
  public void focusGained(FocusEvent e) {}

  public void focusLost(FocusEvent e){
    escapeEdit();
  }

  public void keyPressed(KeyEvent e)
  {
    if (e.getKeyCode() == KeyEvent.VK_ENTER) endEdit();
    else
    if (e.getKeyCode() == KeyEvent.VK_ESCAPE) escapeEdit();
  }

  public void keyReleased(KeyEvent e){}
  public void keyTyped(KeyEvent e) {}

  protected void setValue(String name, String value)
  {
    escapeEdit();
    PropertyDesc desc = (PropertyDesc)properties.get(name);
    desc.valueView.setText(value);
    repaint();
  }

  protected void startEdit(PropertyDesc desc)
  {
    if (selected != desc)
    {
      remove(desc.valueView);
      add(desc.editor);
      desc.editor.setText(desc.valueView.getText());
      desc.editor.setSize(2, 2);
      desc.editor.requestFocus();
      selected = desc;
      doLayout();
    }
  }

  protected void escapeEdit()
  {
    if (selected != null)
    {
      remove(selected.editor);
      add(selected.valueView);
      selected.valueView.setSize(2, 2);
      selected = null;
      doLayout();
    }
  }

  protected void endEdit()
  {
    if (selected != null)
    {
      remove(selected.editor);
      add(selected.valueView);
      String v1 = selected.valueView.getText();
      String v2 = selected.editor.getText();
      selected.valueView.setText(v2);

      if (support != null && !v1.equals(v2))
      {
        String name  = selected.nameView.getText();
        String value = selected.valueView.getText();
        support.firePropertyChange(name, v1, v2);
      }

      selected.valueView.setSize(2, 2);
      selected = null;
      doLayout();
    }
  }
}


class PropertyDesc
{
  Label nameView;
  Label valueView;
  TextField editor;
}


