/**
 *     Caption: Zaval GUI Designer Package
 *     $Revision: 1.51 $
 *     $Date: 2002/06/06 14:30:17 $
 *
 *     @author:     Andrei Vishnevsky
 *     @version:    1.0
 *
 * The Zaval GUI Designer Package (GDP) is set of components that allows to control
 * size, location, cursor types for the Java AWT/Swing components. Actually, the
 * components are Java AWT events listeners that have no GUI part.
 *
 * For more info on this product read Zaval GUI Designer Package Tutorial
 * (It comes within this package).
 * The latest product version is always available from the product's homepage:
 * http://www.zaval.org/products/gdp/
 * and from the SourceForge:
 * http://sourceforge.net/projects/zaval0004/
 *
 * Contacts:
 *   Support : support@zaval.org
 *   Change Requests : change-request@zaval.org
 *   Feedback : feedback@zaval.org
 *   Other : info@zaval.org
 *
 * Copyright (C) 2001-2002  Zaval Creative Engineering Group (http://www.zaval.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * (version 2) as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */
package org.zaval.awt.gdp.demo;

import java.awt.*;
import java.awt.event.*;
import java.util.*;
import java.lang.reflect.*;
import org.zaval.awt.gdp.*;

public class PropertyResolver
{
  public static String getValueAsString(Component c, String name)
  {
    if (name.equals("Size"))
    {
      Dimension d = c.getSize();
      return "" + d.width + "," + d.height;
    }
    else
    if (name.equals("Location"))
    {
      Point p = c.getLocation();
      DgnController current = DgnController.getCurrentDgn();
      if (current != null && current.getTarget() == c)
      {
        p = c.getParent().getLocation();
      }
      return "" + p.x + "," + p.y;
    }
    else
    if (name.equals("Background"))
    {
      Color col = c.getBackground();
      return DemoUtil.parseColor(col);
    }
    else
    if (name.equals("Foreground"))
    {
      Color col = c.getForeground();
      return DemoUtil.parseColor(col);
    }
    else
    if (name.equals("Text"))
    {
      if (c instanceof Label)
      {
        return ((Label)c).getText();
      }
      else
      if (c instanceof Button)
      {
        return ((Button)c).getLabel();
      }
      else
      if (c instanceof TextComponent)
      {
        return ((TextComponent)c).getText();
      }
      else
      if (c instanceof Checkbox)
      {
        return ((Checkbox)c).getLabel();
      }
    }
    else
    if (name.equals("Items"))
    {
      if (c instanceof List)
      {
        String[] items = ((List)c).getItems();
        String   res   = null;
        if (items.length > 0) res = "";
        for (int i=0; i<items.length; i++)
        {
          if (i > 0) res += ";";
          res += items[i];
        }
        return res;
      }
    }
    throw new IllegalArgumentException();
  }


  public static Object getValue(Component c, String name)
  {
    if (name.equals("Size"))
      return c.getSize();
    else
    if (name.equals("Location"))
    {
      DgnController current = DgnController.getCurrentDgn();
      if (current != null && current.getTarget() == c)
        return c.getParent().getLocation();
      else
        return c.getLocation();
    }
    else
    if (name.equals("Background"))
      return c.getBackground();
    else
    if (name.equals("Foreground"))
      return c.getForeground();
    else
    if (name.equals("Text"))
    {
      if (c instanceof Label)
        return ((Label)c).getText();
      else
      if (c instanceof Button)
        return ((Button)c).getLabel();
      else
      if (c instanceof TextComponent)
        return ((TextComponent)c).getText();
      else
      if (c instanceof Checkbox)
        return ((Checkbox)c).getLabel();
    }
    else
    if (name.equals("Items"))
      if (c instanceof List) return ((List)c).getItems();

    throw new IllegalArgumentException();
  }

  public static Object convert2val(String name, String val)
  {
    if (name.equals("Size"))
    {
      StringTokenizer st = new StringTokenizer(val, ",");
      return new Dimension(Integer.parseInt(st.nextToken()),
                           Integer.parseInt(st.nextToken()));
    }
    else
    if (name.equals("Location"))
    {
      StringTokenizer st = new StringTokenizer(val, ",");
      return new Point(Integer.parseInt(st.nextToken()),
                       Integer.parseInt(st.nextToken()));
    }
    else
    if (name.equals("Background") || name.equals("Foreground"))
    {
      return DemoUtil.parseColor(val);
    }
    else
    if (name.equals("Text"))
    {
      return val;
    }
    else
    if (name.equals("Items"))
    {
      StringTokenizer st = new StringTokenizer(val, ";");
      String[] res = new String[st.countTokens()];
      for(int i=0; st.hasMoreTokens(); i++) res[i] = st.nextToken();
      return res;
    }

    throw new IllegalArgumentException();
  }

  public static void setValue(Component c, String name, Object val)
  {
    DgnController current = DgnController.getCurrentDgn();
    if (name.equals("Size"))
    {
      Dimension d = (Dimension)val;
      if (current != null && current.getTarget() == c)
        current.resizeTarget(d.width, d.height);
      else
        c.setSize(d.width, d.height);
    }
    else
    if (name.equals("Location"))
    {
      Point p = (Point)val;
      if (current != null && current.getTarget() == c)
        current.moveTarget(p.x, p.y);
      else
        c.setLocation(p.x, p.y);
    }
    else
    if (name.equals("Background"))
    {
      c.setBackground((Color)val);
    }
    else
    if (name.equals("Foreground"))
    {
      c.setForeground((Color)val);
    }
    else
    if (name.equals("Text"))
    {
      if (c instanceof Label)
      {
        ((Label)c).setText((String)val);
      }
      else
      if (c instanceof Button)
      {
        ((Button)c).setLabel((String)val);
      }
      else
      if (c instanceof TextComponent)
      {
        ((TextComponent)c).setText((String)val);
      }
      else
      if (c instanceof Checkbox)
      {
        ((Checkbox)c).setLabel((String)val);
      }
    }
    else
    if (name.equals("Items"))
    {
      if (c instanceof List)
      {
        List l = (List)c;
        l.removeAll();
        String[] s = (String[])val;
        for (int i=0; i<s.length; i++) l.addItem (s[i]);
      }
    }
  }

  public static String[] getPropertyNames(Component c)
  {
    Vector v = new Vector();
    v.addElement("Size");
    v.addElement("Location");
    v.addElement("Background");
    v.addElement("Foreground");
    if ((c instanceof Label) ||
        (c instanceof Button)||
        (c instanceof Checkbox))
    {
      v.addElement("Text");
    }
    if (c instanceof List) v.addElement("Items");
    String[] res = new String[v.size()];
    for (int i=0; i<res.length; i++) res[i] = (String)v.elementAt(i);
    return res;
  }
}

