/**
 *     Caption: Zaval GUI Designer Package
 *     $Revision: 1.51 $
 *     $Date: 2002/06/06 14:30:17 $
 *
 *     @author:     Andrei Vishnevsky
 *     @version:    1.0
 *
 * The Zaval GUI Designer Package (GDP) is set of components that allows to control
 * size, location, cursor types for the Java AWT/Swing components. Actually, the
 * components are Java AWT events listeners that have no GUI part.
 *
 * For more info on this product read Zaval GUI Designer Package Tutorial
 * (It comes within this package).
 * The latest product version is always available from the product's homepage:
 * http://www.zaval.org/products/gdp/
 * and from the SourceForge:
 * http://sourceforge.net/projects/zaval0004/
 *
 * Contacts:
 *   Support : support@zaval.org
 *   Change Requests : change-request@zaval.org
 *   Feedback : feedback@zaval.org
 *   Other : info@zaval.org
 *
 * Copyright (C) 2001-2002  Zaval Creative Engineering Group (http://www.zaval.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * (version 2) as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */
package org.zaval.awt.gdp.demo;

import java.awt.*;
import java.awt.event.*;
import java.beans.*;
import java.util.*;
import java.io.*;
import java.lang.reflect.*;

import org.zaval.awt.*;
import org.zaval.awt.gdp.*;
import org.zaval.awt.gdp.event.*;

public class ToolPanel
extends BorderPanel
implements DgnComponent, MouseListener
{
  private Hashtable  toolItems;
  private Vector     toolItemsVector;
  private ToolItem   selected;
  private Label      comment = new Label();
  private SpeedButton clean, cleanAll;

  public ToolPanel()
  {
    super(ETCHED);
    setLayout(new BorderLayout());
    Panel p = new Panel();
    p.setLayout(new FlowLayout(FlowLayout.LEFT));
    add ("West", p);
    add ("East", comment);
    comment.setFont (new Font("Helvetica", Font.BOLD, 12));
    comment.setForeground(Color.blue);

    loadToolItems();
    for (int i=0; i < toolItemsVector.size(); i++)
    {
      ToolItem item = (ToolItem)toolItemsVector.elementAt(i);
      BorderPanel bp = new BorderPanel(0);
      bp.setLayout(new BorderLayout());
      bp.add ("Center", item.comp);
      p.add (bp);
    }

    p.add(new Line());
    clean = new SpeedButton(ComponentUtil.getImage("rs/delete.gif", getClass(), this));
    cleanAll = new SpeedButton(ComponentUtil.getImage("rs/clean.gif", getClass(), this));
    p.add(clean);
    p.add(cleanAll);

    setBackground (Color.lightGray);
    addMouseListener(this);
  }

  public SpeedButton getCleanButton() {
    return clean;
  }

  public SpeedButton getCleanAllButton() {
    return cleanAll;
  }

  public void mouseClicked(MouseEvent e) {}
  public void mouseReleased(MouseEvent e) {}
  public void mouseEntered(MouseEvent e) {}
  public void mouseExited(MouseEvent e) {}

  public void mousePressed(MouseEvent e)
  {
    Component target = e.getComponent();
    if (target == this)
    {
      clearSelection();
    }
    else
    {
      if (selected != null) deselect(selected.comp);
      select(target);
      selected =(ToolItem)toolItems.get(target);
      comment.setText(selected.className);
      comment.invalidate();
      doLayout();
    }
  }

  public void clearSelection()
  {
    if (selected != null)
    {
      deselect(selected.comp);
      comment.setText("");
      selected = null;
      doLayout();
    }
  }

  public ToolItem getSelected () {
    return selected;
  }

  protected void select(Component c) {
    ((BorderPanel)c.getParent()).setBorderType(4);
  }

  protected void deselect(Component c) {
    ((BorderPanel)c.getParent()).setBorderType(0);
  }

  protected void loadToolItems()
  {
    selected = null;
    if (toolItems == null) toolItems = new Hashtable();
    else                   toolItems.clear();

    if (toolItemsVector == null) toolItemsVector = new Vector();
    else
    {
      for(int i=0; i < toolItemsVector.size(); i++)
      {
        ToolItem item = (ToolItem)toolItemsVector.elementAt(i);
        item.comp.removeMouseListener(this);
        item.cursor.setTarget(null);
      }
      toolItemsVector.removeAllElements();
    }

    try {
      InputStream is = getClass().getResourceAsStream("rs/toolitems.properties");
      Properties  p  = new Properties();
      p.load(is);

      SimpleCursorInfo ctype = new SimpleCursorInfo(Cursor.HAND_CURSOR);
      StringTokenizer st = new StringTokenizer(p.getProperty("items"), ",");
      for(int i=0; st.hasMoreTokens(); i++)
      {
        String token = st.nextToken();
        ToolItem toolItem = new ToolItem();
        toolItem.iconName  = p.getProperty(token + ".icon");
        toolItem.className = p.getProperty(token + ".class");
        toolItem.args      = p.getProperty(token + ".args");

        String size = p.getProperty(token + ".size");
        if (size != null)
        {
          StringTokenizer stSize = new StringTokenizer(size, ",");
          toolItem.size = new Dimension (Integer.parseInt(stSize.nextToken()), Integer.parseInt(stSize.nextToken()));
        }
        else
          toolItem.size = new Dimension (100, 35);

        toolItem.comp = new ImageCanvas(ComponentUtil.getImage(toolItem.iconName, getClass(), this));
        toolItem.comp.addMouseListener(this);
        toolItem.cursor = new CursorController(toolItem.comp, ctype);
        toolItems.put (toolItem.comp, toolItem);
        toolItemsVector.addElement (toolItem);
      }
    }
    catch (IOException e) {
      e.printStackTrace();
    }
  }
}



