/**
 *     Caption: Zaval GUI Designer Package
 *     $Revision: 1.51 $
 *     $Date: 2002/06/06 14:30:17 $
 *
 *     @author:     Andrei Vishnevsky
 *     @version:    1.0
 *
 * The Zaval GUI Designer Package (GDP) is set of components that allows to control
 * size, location, cursor types for the Java AWT/Swing components. Actually, the
 * components are Java AWT events listeners that have no GUI part.
 *
 * For more info on this product read Zaval GUI Designer Package Tutorial
 * (It comes within this package).
 * The latest product version is always available from the product's homepage:
 * http://www.zaval.org/products/gdp/
 * and from the SourceForge:
 * http://sourceforge.net/projects/zaval0004/
 *
 * Contacts:
 *   Support : support@zaval.org
 *   Change Requests : change-request@zaval.org
 *   Feedback : feedback@zaval.org
 *   Other : info@zaval.org
 *
 * Copyright (C) 2001-2002  Zaval Creative Engineering Group (http://www.zaval.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * (version 2) as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */
package org.zaval.awt;

import java.awt.*;
import java.io.*;

public class ComponentUtil
{
   public static final int DOT     = 1;
   public static final int PLAIN   = 2;

   public static final int DOT_GAP  = 2;
   public static final int DOT_SIZE = 3;

   public static Point getAbsLocation(Component parent, Component c)
   {
     Point     l = c.getLocation();
     Component p = c.getParent();
     while (parent != p && p != null)
     {
       Point ll = p.getLocation();
       l.x += ll.x;
       l.y += ll.y;
       p = p.getParent();
     }
     return p == null?null:l;
   }

   public static Point getRelLocation(int x, int y, Component parent, Component c)
   {
     Point l = new Point(x, y);
     while (parent != c && c != null)
     {
       Point ll = c.getLocation();
       l.x -= ll.x;
       l.y -= ll.y;
       c = c.getParent();
     }
     return c == null?null:l;
   }

   public static void drawHLine(Graphics g, int x1, int x2, int y, Color col, int style)
   {
     g.setColor(col);
     if (style == PLAIN) g.drawLine(x1, y, x2, y);
     else
     {
       int w     = x2 - x1;
       int ww    = DOT_SIZE + DOT_GAP;
       int count = w/ww;
       if ((w%ww) > 0) count++;
       for (int i=0; i<count; i++)
       {
         int xx = x1;
         if (xx > x2) xx = x2;
         g.drawLine(x1, y, xx, y);
         x1 += ww;
       }
     }
   }

   public static void drawHLineOnComponent(Component c, int x1, int x2, int y, Color col, int style)
   {
     if (c == null) return;
     Dimension d = c.getSize();
     if (d.width <= x2) x2 = d.width-1;

     Graphics  g = c.getGraphics();
     g.setXORMode(Color.white);
     drawHLine(g, x1, x2, y, col, style);
     g.dispose();

     Component lc = getNextLeftChild(c, x1 + 1, y);
     int xx1, xx2;
     while (lc != null && x1 < x2)
     {
       Rectangle lr = lc.getBounds();
       xx1 = x1 - lr.x;
       if (xx1 < 0) xx1 = 0;

       xx2 = x2 - lr.x;
       if (xx2 >= lr.width) xx2 = lr.width-1;

       int yy = y - lr.y;
       if (xx2 <= xx1) break;

       drawHLineOnComponent(lc, xx1, xx2, yy, col, style);

       x1 = (lr.x + lr.width);
       lc = getNextLeftChild(c, x1, y);
     }
   }

   public static void drawRectOnComponent(Component c, int x, int y, int w, int h, Color col) {
     drawRectOnComponent(c, x, y, w, h, col, PLAIN);
   }

   public static void drawRectOnComponent(Component c, int x, int y, int w, int h, Color col, int style)
   {
     drawHLineOnComponent(c, x, x+w, y,   col, style);
     drawHLineOnComponent(c, x, x+w, y+h, col, style);
     drawVLineOnComponent(c, y, y+h, x,   col, style);
     drawVLineOnComponent(c, y, y+h, x+w, col, style);
   }

   public static void drawVLine(Graphics g, int y1, int y2, int x, Color col, int style)
   {
     g.setColor(col);
     if (style == PLAIN) g.drawLine(x, y1, x, y2);
     else
     {
       int h     = y2 - y1;
       int hh    = DOT_SIZE + DOT_GAP;
       int count = h/hh;
       if ((h%hh) > 0) count++;
       for (int i=0; i<count; i++)
       {
         int yy = y1;
         if (yy > y2) yy = y2;
         g.drawLine(x, y1, x, yy);
         y1 += hh;
       }
     }
   }

   public static void drawVLineOnComponent(Component c, int y1, int y2, int x, Color col, int style)
   {
     if (c == null) return;
     Dimension d = c.getSize();
     if (d.height <= y2) y2 = d.height-1;

     Graphics  g = c.getGraphics();
     g.setXORMode(Color.white);
     drawVLine(g, y1, y2, x, col, style);
     g.dispose();

     Component lc = getNextBottomChild(c, y1 + 1, x);
     int yy1, yy2;
     while (lc != null && y1 < y2)
     {
       Rectangle lr = lc.getBounds();
       yy1 = y1 - lr.y;
       if (yy1 < 0) yy1 = 0;

       yy2 = y2 - lr.y;
       if (yy2 >= lr.height) yy2 = lr.height-1;

       int xx = x - lr.x;
       if (yy2 <= yy1) break;

       drawVLineOnComponent(lc, yy1, yy2, xx, col, style);

       y1 = (lr.y + lr.height);
       lc = getNextBottomChild(c, y1, x);
     }
   }

   public static Component getComponentAt(Component top, int x, int y)
   {
     Component c = top.getComponentAt(x, y);
     while (c != null && c != top)
     {
       if (!(c instanceof Container)) return c;
       Point l = c.getLocation();
       top = (Container)c;
       x -= l.x;
       y -= l.y;
       c = top.getComponentAt(x, y);
     }
     return top;
   }

   public static Container getContainerAt(Container top, int x, int y) {
     Component c = getComponentAt(top, x, y);
     return (c instanceof Container)?(Container)c:c.getParent();
   }

   public static Component getNextBottomChild(Component parent, int y, int x)
   {
     if (!(parent instanceof Container)) return null;

     Component c = parent.getComponentAt(x, y);
     if (c != null && c != parent) return c;

     Component[] comps = ((Container)parent).getComponents();
     Component   find  = null;
     int         fy    = Integer.MAX_VALUE;
     for (int i=0; i<comps.length; i++)
     {
       Rectangle r = comps[i].getBounds();
       if (x < r.x || x > (r.x + r.width)) continue;

       if (r.y < fy && r.y > y)
       {
         fy   = r.y;
         find = comps[i];
       }
     }
     return find;
   }

   public static Component getNextLeftChild(Component parent, int x, int y)
   {
     if (!(parent instanceof Container)) return null;

     Component c = parent.getComponentAt(x, y);
     if (c != null && c != parent) return c;

     Component[] comps = ((Container)parent).getComponents();
     Component   find  = null;
     int         fx    = Integer.MAX_VALUE;
     for (int i=0; i<comps.length; i++)
     {
       Rectangle r = comps[i].getBounds();
       if (y < r.y || y > (r.y + r.height)) continue;

       if (r.x < fx && r.x > x)
       {
         fx   = r.x;
         find = comps[i];
       }
     }
     return find;
   }

   public static Image getImage(String name, Class cl, Component observer)
   {
     InputStream is = cl.getResourceAsStream(name);
     if (is == null)
     {
       System.out.println ("Can not find " + name);
       return null;
     }
     ByteArrayOutputStream bo = new ByteArrayOutputStream();
     byte[] buf   = new byte[512];
     int    count = 0;
     Image img = null;
     try {
       while ((count = is.read(buf, 0, buf.length))>=0)
         bo.write(buf, 0, count);
       img = Toolkit.getDefaultToolkit().createImage(bo.toByteArray());

       MediaTracker media = new MediaTracker(observer);
       media.addImage(img, 0);
       media.waitForID(0);
       if (media.isErrorID(0)) System.out.println ("Cannot load " + name);
     }
     catch (Exception e) {
       e.printStackTrace();
       return null;
     }
     finally {
       try {
         if (is != null) is.close();
       } catch(Exception ee) {}
     }

     return img;
   }
}
