/**
 *     Caption: Zaval GUI Designer Package
 *     $Revision: 1.51 $
 *     $Date: 2002/06/06 14:30:17 $
 *
 *     @author:     Andrei Vishnevsky
 *     @version:    1.0
 *
 * The Zaval GUI Designer Package (GDP) is set of components that allows to control
 * size, location, cursor types for the Java AWT/Swing components. Actually, the
 * components are Java AWT events listeners that have no GUI part.
 *
 * For more info on this product read Zaval GUI Designer Package Tutorial
 * (It comes within this package).
 * The latest product version is always available from the product's homepage:
 * http://www.zaval.org/products/gdp/
 * and from the SourceForge:
 * http://sourceforge.net/projects/zaval0004/
 *
 * Contacts:
 *   Support : support@zaval.org
 *   Change Requests : change-request@zaval.org
 *   Feedback : feedback@zaval.org
 *   Other : info@zaval.org
 *
 * Copyright (C) 2001-2002  Zaval Creative Engineering Group (http://www.zaval.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * (version 2) as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */
package org.zaval.awt.gdp;

import java.awt.*;

/**
 * <font face="Arial" size="2">
 * This layout manager is supposed to be used for designer container components.
 * </font>
 */
public class DgnContainerLayout
implements LayoutManager
{
  /**
   * <font face="Arial" size="2">
   * Lays out the container in the specified panel.
   * @param <code>p</code> the component which needs to be laid out.
   * </font>
   */
   public void layoutContainer(Container p)
   {
     if (p.getComponentCount() > 0)
     {
       Component target = p.getComponent(0);
       if (target.isVisible())
       {
         Insets    i = p.getInsets();
         Dimension d = p.getSize();
         target.setBounds(i.left, i.top, d.width - i.left - i.right, d.height - i.top - i.bottom);
       }
     }
   }

  /**
   * <font face="Arial" size="2">
   * Calculates the minimum size dimensions for the specified
   * panel given the components in the specified parent container.
   * @param <code>p</code> the component to be laid out
   * </font>
   */
   public Dimension minimumLayoutSize(Container p) {
     Insets i = p.getInsets();
     return new Dimension(i.left + i.right, i.top + i.bottom);
   }

  /**
   * <font face="Arial" size="2">
   * Calculates the preferred size dimensions for the specified
   * panel given the components in the specified parent container.
   * @param <code>p</code> the component to be laid out
   * </font>
   */
   public Dimension preferredLayoutSize(Container p)
   {
     if (p.getComponentCount() > 0)
     {
       Component target = p.getComponent(0);
       if (target.isVisible())
       {
         Insets i = p.getInsets();
         Dimension d = target.getSize();
         d.width   += (i.left + i.right);
         d.height  += (i.top + i.bottom);
         return d;
       }
     }
     return minimumLayoutSize(p);
   }

  /**
   * <font face="Arial" size="2">
   * Removes the specified component from the layout.
   * @param <code>comp</code> the component ot be removed
   * </font>
   */
   public void removeLayoutComponent(Component comp) { }

  /**
   * <font face="Arial" size="2">
   * Adds the specified component with the specified name to
   * the layout.
   * @param <code>name</code> the component name.
   * @param <code>c</code> the component to be added.
   * </font>
   */
   public void addLayoutComponent(String name, Component c) {}
}
