/**
 *     Caption: Zaval GUI Designer Package
 *     $Revision: 1.51 $
 *     $Date: 2002/06/06 14:30:17 $
 *
 *     @author:     Andrei Vishnevsky
 *     @version:    1.0
 *
 * The Zaval GUI Designer Package (GDP) is set of components that allows to control
 * size, location, cursor types for the Java AWT/Swing components. Actually, the
 * components are Java AWT events listeners that have no GUI part.
 *
 * For more info on this product read Zaval GUI Designer Package Tutorial
 * (It comes within this package).
 * The latest product version is always available from the product's homepage:
 * http://www.zaval.org/products/gdp/
 * and from the SourceForge:
 * http://sourceforge.net/projects/zaval0004/
 *
 * Contacts:
 *   Support : support@zaval.org
 *   Change Requests : change-request@zaval.org
 *   Feedback : feedback@zaval.org
 *   Other : info@zaval.org
 *
 * Copyright (C) 2001-2002  Zaval Creative Engineering Group (http://www.zaval.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * (version 2) as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */
package org.zaval.awt.gdp;

import java.awt.*;

/**
 * <font face="Arial" size="2">
 * This cursor info implementation is supposed to be used for designer container components.
 * </font>
 */
public class DgnCursorInfo
implements CursorInfo
{
  /**
   * <font face="Arial" size="2">
   * Returns the cursor type for the specified component and location relatively the component.
   * @param <code>target</code> the specified component.
   * @param <code>x</code> the specified x coordinate relatively the component.
   * @param <code>y</code> the specified y coordinate relatively the component.
   * </font>
   */
   public int getCursorType (Component target, int x, int y)
   {
     Insets    i = (target instanceof Container)?((Container)target).getInsets():new Insets(6, 6, 6, 6);
     Dimension d = target.getSize();
     Rectangle r = new Rectangle(i.left, i.top, d.width - i.left - i.right, d.height - i.top - i.bottom);
     if (r.contains(x, y)) return -1;

     if ((new Rectangle (0, 0, i.left, i.top)).contains(x, y))
       return Cursor.NW_RESIZE_CURSOR;

     if ((new Rectangle (d.width - i.right, d.height - i.bottom, i.right, i.bottom)).contains(x, y))
       return Cursor.SE_RESIZE_CURSOR;

     if ((new Rectangle (0, d.height - i.bottom, i.left, i.bottom)).contains(x, y))
       return Cursor.SW_RESIZE_CURSOR;

     if ((new Rectangle (d.width - i.right, 0, i.right, i.top)).contains(x, y))
       return Cursor.NE_RESIZE_CURSOR;

     int cx = (d.width - i.top)/2;
     if ((new Rectangle (cx, 0, i.top, i.top)).contains(x, y))
       return Cursor.N_RESIZE_CURSOR;

     cx = (d.width - i.bottom)/2;
     if ((new Rectangle (cx, d.height - i.bottom, i.bottom, i.bottom)).contains(x, y))
       return Cursor.S_RESIZE_CURSOR;

     int cy = (d.height - i.left)/2;
     if ((new Rectangle (0, cy, i.left, i.left)).contains(x, y))
       return Cursor.W_RESIZE_CURSOR;

     cy = (d.height - i.right)/2;
     if ((new Rectangle (d.width - i.right, cy, i.right, i.right)).contains(x, y))
       return Cursor.E_RESIZE_CURSOR;

     return Cursor.MOVE_CURSOR;
   }
}
