/**
 *     Caption: Zaval GUI Designer Package
 *     $Revision: 1.51 $
 *     $Date: 2002/06/06 14:30:17 $
 *
 *     @author:     Andrei Vishnevsky
 *     @version:    1.0
 *
 * The Zaval GUI Designer Package (GDP) is set of components that allows to control
 * size, location, cursor types for the Java AWT/Swing components. Actually, the
 * components are Java AWT events listeners that have no GUI part.
 *
 * For more info on this product read Zaval GUI Designer Package Tutorial
 * (It comes within this package).
 * The latest product version is always available from the product's homepage:
 * http://www.zaval.org/products/gdp/
 * and from the SourceForge:
 * http://sourceforge.net/projects/zaval0004/
 *
 * Contacts:
 *   Support : support@zaval.org
 *   Change Requests : change-request@zaval.org
 *   Feedback : feedback@zaval.org
 *   Other : info@zaval.org
 *
 * Copyright (C) 2001-2002  Zaval Creative Engineering Group (http://www.zaval.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * (version 2) as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */
package org.zaval.awt.gdp;

import java.awt.*;
import javax.swing.*;

/**
 * <font face="Arial" size="2">
 * This is Java Swing panel that can be used as a designer container for a Swing component.
 * The panel paints special border and implements CursorInfo interface to define resize cursor,
 * move cursor types for different part of the border area. The class implements
 * the layout manager interface that layouts the specified child component in the centre
 * of the container with the specified gap (the gap defines left, right, top and bottom
 * indents).
 * </font>
 */
public class JDgnContainer
extends JPanel
implements DgnComponent
{
   private int   gap    = 6;
   private Color rColor = Color.blue;

  /**
   * <font face="Arial" size="2">
   * Constructs a new designer container.
   * </font>
   */
   public JDgnContainer()  {
     this(null);
   }

  /**
   * <font face="Arial" size="2">
   * Constructs a new designer container with the specified child component.
   * @param <code>c</code> the specified child component.
   * </font>
   */
   public JDgnContainer(Component c) {
     setLayout(new DgnContainerLayout());
     if (c != null) add(c);
   }

  /**
   * <font face="Arial" size="2">
   * Gets the gap that actually is used as insets. The gap defines left, top, bottom and
   * right indents.
   * @return a gap.
   * </font>
   */
   public int getGap() {
     return gap;
   }

  /**
   * <font face="Arial" size="2">
   * Sets the specified gap that actually defines the container insets
   * @param <code>g</code> the specified gap.
   * </font>
   */
   public void setGap(int g)
   {
     if (gap != g)
     {
       gap = g;
       invalidate();
       repaint();
     }
   }

  /**
   * <font face="Arial" size="2">
   * Determines the insets of this container, which indicate the size
   * of the container's border. The implementation returns the gap as the insets top,
   * left, bottom and right fields value.
   * @return the insets of this container.
   * </font>
   */
   public Insets getInsets() {
     return new Insets(gap, gap, gap, gap);
   }

  /**
   * <font face="Arial" size="2">
   * Paints this component. This method is called when the contents
   * of the component should be painted in response to the component
   * first being shown or damage needing repair. The method is overrided to
   * paint the design border.
   * @param <code>g</code> the graphics context to use for painting.
   * </font>
   */
   public void paint(Graphics g)
   {
     super.paint(g);
     Dimension d  = getSize();
     int cx = (d.width  - gap)/2;
     int cy = (d.height - gap)/2;

     g.setColor(rColor);
     g.fillRect(0, 0, gap, gap);
     g.fillRect(cx, 0, gap, gap);
     g.fillRect(0, cy, gap, gap);
     g.fillRect(d.width - gap, 0, gap, gap);


     g.fillRect(0, d.height - gap, gap, gap);
     g.fillRect(cx, d.height - gap, gap, gap);
     g.fillRect(d.width - gap, cy, gap, gap);
     g.fillRect(d.width - gap, d.height - gap, gap, gap);

     g.drawRect(gap/2, gap/2, d.width - gap, d.height- gap);
   }

  /**
   * <font face="Arial" size="2">
   * Sets the specified color for the designer border.
   * @param <code>c</code> the specified color.
   * </font>
   */
   public void setRectangleColor(Color c)
   {
     if (!c.equals(rColor))
     {
       rColor = c;
       repaint();
     }
   }

  /**
   * <font face="Arial" size="2">
   * Gets the designer border color.
   * @return a designer border color.
   * </font>
   */
   public Color getRectangleColor() {
     return rColor;
   }
}
