/**
 *     Caption: Zaval GUI Designer Package
 *     $Revision: 1.51 $
 *     $Date: 2002/06/06 14:30:17 $
 *
 *     @author:     Andrei Vishnevsky
 *     @version:    1.0
 *
 * The Zaval GUI Designer Package (GDP) is set of components that allows to control
 * size, location, cursor types for the Java AWT/Swing components. Actually, the
 * components are Java AWT events listeners that have no GUI part.
 *
 * For more info on this product read Zaval GUI Designer Package Tutorial
 * (It comes within this package).
 * The latest product version is always available from the product's homepage:
 * http://www.zaval.org/products/gdp/
 * and from the SourceForge:
 * http://sourceforge.net/projects/zaval0004/
 *
 * Contacts:
 *   Support : support@zaval.org
 *   Change Requests : change-request@zaval.org
 *   Feedback : feedback@zaval.org
 *   Other : info@zaval.org
 *
 * Copyright (C) 2001-2002  Zaval Creative Engineering Group (http://www.zaval.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * (version 2) as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */
package org.zaval.awt.gdp;

import java.awt.*;
import javax.swing.*;

/**
 * <font face="Arial" size="2">
 * This a library adapter implementation that is supposed to be used with Java Swing library.
 * </font>
 */
public class JLibraryAdapter
extends LibraryAdapter
{
 /**
  * <font face="Arial" size="2">
  * Draws the specified rectangle for the component using the given color.
  * This method allows to render rectangle over the specified area and the area can be out of
  * the component bounds.
  * @param <code>c</code> the specified component.
  * @param <code>x</code> the x coordinate of the left-top corner of the rendered rectangle.
  * @param <code>y</code> the y coordinate of the left-top corner of the rendered rectangle.
  * @param <code>w</code> the width of the rendered rectangle.
  * @param <code>h</code> the height of the rendered rectangle.
  * @param <code>col</code> the color of the rendered rectangle.
  * </font>
  */
  public void drawRectOnComponent(Component c, int x, int y, int w, int h, Color col)
  {
    Graphics g = c.getGraphics();
    try {
      g.setXORMode(Color.white);
      g.setColor(col);
      g.drawRect (x, y, w - 1, h - 1);
      RepaintManager.currentManager(c).paintDirtyRegions();
    }
    finally { if (g != null) g.setPaintMode(); }
  }

 /**
  * <font face="Arial" size="2">
  * Makes and returns the special container component that supposed to be used with
  * DgnController class as a designer container.
  * @return a designer container.
  * </font>
  */
  public Container makeDgnContainer () {
    return new JDgnContainer();
  }

 /**
  * <font face="Arial" size="2">
  * Returns a top-level parent component for the specified child component.
  * @param <code>target</code> the specified child component.
  * @return a top-level parent container.
  * </font>
  */
  public Container getRootContainer (Component target) {
    return ((JComponent)target).getRootPane().getContentPane();
  }
}

