/**
 *     Caption: Zaval GUI Designer Package
 *     $Revision: 1.51 $
 *     $Date: 2002/06/06 14:30:17 $
 *
 *     @author:     Andrei Vishnevsky
 *     @version:    1.0
 *
 * The Zaval GUI Designer Package (GDP) is set of components that allows to control
 * size, location, cursor types for the Java AWT/Swing components. Actually, the
 * components are Java AWT events listeners that have no GUI part.
 *
 * For more info on this product read Zaval GUI Designer Package Tutorial
 * (It comes within this package).
 * The latest product version is always available from the product's homepage:
 * http://www.zaval.org/products/gdp/
 * and from the SourceForge:
 * http://sourceforge.net/projects/zaval0004/
 *
 * Contacts:
 *   Support : support@zaval.org
 *   Change Requests : change-request@zaval.org
 *   Feedback : feedback@zaval.org
 *   Other : info@zaval.org
 *
 * Copyright (C) 2001-2002  Zaval Creative Engineering Group (http://www.zaval.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * (version 2) as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */
package org.zaval.awt.gdp;

import java.awt.*;
import org.zaval.awt.*;

/**
 * <font face="Arial" size="2">
 * This class is used with the controllers set of the package as a midleware layer.
 * The class includes set of methods that is a specific for a GUI library for that the
 * package is going to be used.
 * <p>
 * Use <code>getLibraryAdapter</code> method to get current adapter and
 * <code>setLibraryAdapter</code> method to set the adapter. The package provides
 * following two adapters:
 * <ul>
 *   <li>
 *     LibraryAdapter to be used with Java AWT library. The adapter is set as default.
 *   </li>
 *   <li>
 *     JLibraryAdapter to be used with Java Swing library.
 *   </li>
 * </ul>
 * </font>
 */
public class LibraryAdapter
{
  private static LibraryAdapter adapter;

 /**
  * <font face="Arial" size="2">
  * Sets the specified adapter.
  * @param <code>a</code> the specified adapter.
  * </font>
  */
  public synchronized static void  setLibraryAdapter(LibraryAdapter a) {
    if (adapter != a) adapter = a;
  }

 /**
  * <font face="Arial" size="2">
  * Gets the current adapter.
  * @return a current adapter.
  * </font>
  */
  public synchronized static LibraryAdapter getLibraryAdapter() {
    return adapter;
  }

 /**
  * <font face="Arial" size="2">
  * Draws the specified rectangle for the component using the given color.
  * This method allows to render rectangle over the specified area and the area can be out of
  * the component bounds.
  * @param <code>c</code> the specified component.
  * @param <code>x</code> the x coordinate of the left-top corner of the rendered rectangle.
  * @param <code>y</code> the y coordinate of the left-top corner of the rendered rectangle.
  * @param <code>w</code> the width of the rendered rectangle.
  * @param <code>h</code> the height of the rendered rectangle.
  * @param <code>col</code> the color of the rendered rectangle.
  * </font>
  */
  public void drawRectOnComponent(Component c, int x, int y, int w, int h, Color col) {
    ComponentUtil.drawRectOnComponent(c, x, y, w - 1, h - 1, col);
  }

 /**
  * <font face="Arial" size="2">
  * Makes and returns the special container component that supposed to be used with
  * DgnController class as a designer container.
  * @return a designer container.
  * </font>
  */
  public Container makeDgnContainer() {
    return new DgnContainer();
  }

 /**
  * <font face="Arial" size="2">
  * Returns a top-level parent component for the specified child component.
  * @param <code>target</code> the specified child component.
  * @return a top-level parent container.
  * </font>
  */
  public Container getRootContainer(Component target)
  {
    Container p = target.getParent();
    while(p != null && (!(p instanceof Window)))
    {
      target = p;
      p = target.getParent();
    }

    if (p instanceof Window) return p;
    if (target instanceof Container) return (Container)target;
    return null;
  }

  static {
    setLibraryAdapter(new LibraryAdapter());
  }
}


