/**
 *     Caption: Zaval GUI Designer Package
 *     $Revision: 1.51 $
 *     $Date: 2002/06/06 14:30:17 $
 *
 *     @author:     Andrei Vishnevsky
 *     @version:    1.0
 *
 * The Zaval GUI Designer Package (GDP) is set of components that allows to control
 * size, location, cursor types for the Java AWT/Swing components. Actually, the
 * components are Java AWT events listeners that have no GUI part.
 *
 * For more info on this product read Zaval GUI Designer Package Tutorial
 * (It comes within this package).
 * The latest product version is always available from the product's homepage:
 * http://www.zaval.org/products/gdp/
 * and from the SourceForge:
 * http://sourceforge.net/projects/zaval0004/
 *
 * Contacts:
 *   Support : support@zaval.org
 *   Change Requests : change-request@zaval.org
 *   Feedback : feedback@zaval.org
 *   Other : info@zaval.org
 *
 * Copyright (C) 2001-2002  Zaval Creative Engineering Group (http://www.zaval.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * (version 2) as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */
package org.zaval.awt.gdp;

import java.awt.*;

/**
 * <font face="Arial" size="2">
 * This class is a simple implementation of CursorInfo interface. Using the implementation
 * it is possible to bind the cursor type with the specified target component.
 * </font>
 */
public class SimpleCursorInfo
implements CursorInfo
{
  private int type = -1;

 /**
  * <font face="Arial" size="2">
  * Constructs a new simple cursor info with the specified cursor type.
  * The class will always return the cursor type by <code>getCursorType</code>
  * method.
  * @param <code>t</code> the specified cursor type.
  * </font>
  */
  public SimpleCursorInfo(int t) {
   setCursorType(t);
  }

 /**
  * <font face="Arial" size="2">
  * Sets the specified cursor type that will be returnd by <code>getCursorType</code>
  * method.
  * @param <code>t</code> the specified cursor type.
  * </font>
  */
  public void setCursorType (int t) {
    if (t != type) type = t;
  }

 /**
  * <font face="Arial" size="2">
  * Returns the cursor type for the specified component and location relatively the component.
  * The method implementation returns a cursor type that has been defined by <code>setCursorType</code>
  * method or during the class initialization.
  * @param <code>target</code> the specified component.
  * @param <code>x</code> the specified x coordinate relatively the component.
  * @param <code>y</code> the specified y coordinate relatively the component.
  * </font>
  */
  public int getCursorType (Component target, int x, int y) {
    return type;
  }
}
