/**
 *     Caption: Zaval GUI Designer Package
 *     $Revision: 1.51 $
 *     $Date: 2002/06/06 14:30:17 $
 *
 *     @author:     Andrei Vishnevsky
 *     @version:    1.0
 *
 * The Zaval GUI Designer Package (GDP) is set of components that allows to control
 * size, location, cursor types for the Java AWT/Swing components. Actually, the
 * components are Java AWT events listeners that have no GUI part.
 *
 * For more info on this product read Zaval GUI Designer Package Tutorial
 * (It comes within this package).
 * The latest product version is always available from the product's homepage:
 * http://www.zaval.org/products/gdp/
 * and from the SourceForge:
 * http://sourceforge.net/projects/zaval0004/
 *
 * Contacts:
 *   Support : support@zaval.org
 *   Change Requests : change-request@zaval.org
 *   Feedback : feedback@zaval.org
 *   Other : info@zaval.org
 *
 * Copyright (C) 2001-2002  Zaval Creative Engineering Group (http://www.zaval.org)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * (version 2) as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */
package org.zaval.util.event;

/**
 * <font face="Arial" size="2">
 * This abstract class represents an event that has unique integer identifier.
 * You can inherit the class to create own event classes that may be identified by an
 * integer id.
 * </font>
 */
public abstract class EvObject
extends java.util.EventObject
{
  private int id;

 /**
  * <font face="Arial" size="2">
  * Constructs the event object with the specified source object and the event id.
  * @param <code>src</code> the object where the event originated.
  * @param <code>id</code> the specified event id.
  * </font>
  */
  public EvObject(Object src, int id)
  {
    super(src);
    if (!checkID(id)) throw new IllegalArgumentException();
    this.id = id;
  }

 /**
  * <font face="Arial" size="2">
  * Gets the event id.
  * @return an event id.
  * </font>
  */
  public int getID () {
    return id;
  }

 /**
  * <font face="Arial" size="2">
  * The method returns <code>true</code> if the specified id is valid for the event,
  * otherwise returns <code>false</code>. The method is called with the event constructor
  * to test if the event id is valid and if the event is not valid the IllegalArgumentException
  * will be thrown.
  * @param <code>id</code> the specified id.
  * </font>
  */
  protected abstract boolean checkID(int id);
}
